Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6534)

Unified Diff: chrome/browser/safe_browsing/protocol_manager.h

Issue 160225: Fix the root cause of flakiness in SafeBrowsingProtocolManagerTest.TestGetHashBackOffTimes (Closed)
Patch Set: Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/safe_browsing/protocol_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/safe_browsing/protocol_manager.h
diff --git a/chrome/browser/safe_browsing/protocol_manager.h b/chrome/browser/safe_browsing/protocol_manager.h
index ad6ec2f167c84e64cdac4f4961033c5bbb1c2ec2..ff67795cff2d34c9233d382a40d5407356758523 100644
--- a/chrome/browser/safe_browsing/protocol_manager.h
+++ b/chrome/browser/safe_browsing/protocol_manager.h
@@ -46,8 +46,7 @@ class SafeBrowsingProtocolManager : public URLFetcher::Delegate {
// Testing friends:
FRIEND_TEST(SafeBrowsingProtocolManagerTest, TestBackOffTimes);
FRIEND_TEST(SafeBrowsingProtocolManagerTest, TestChunkStrings);
- FRIEND_TEST(SafeBrowsingProtocolManagerTest,
- DISABLED_TestGetHashBackOffTimes);
+ FRIEND_TEST(SafeBrowsingProtocolManagerTest, TestGetHashBackOffTimes);
public:
SafeBrowsingProtocolManager(SafeBrowsingService* sb_service,
@@ -146,8 +145,9 @@ class SafeBrowsingProtocolManager : public URLFetcher::Delegate {
// issue the request.
void HandleReKey();
- // Update internal state for each GetHash response error.
- void HandleGetHashError();
+ // Update internal state for each GetHash response error, assuming that the
+ // current time is |now|.
+ void HandleGetHashError(const base::Time& now);
// Helper function for update completion.
void UpdateFinished(bool success);
« no previous file with comments | « no previous file | chrome/browser/safe_browsing/protocol_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698